Documentation
¶
Overview ¶
The XGB package implements the X11 core protocol. It is based on XCB: http://xcb.freedesktop.org/
Index ¶
- Constants
- type AllocColorCellsReply
- type AllocColorPlanesReply
- type AllocColorReply
- type AllocNamedColorReply
- type Arc
- type ButtonPressEvent
- type ButtonReleaseEvent
- type Char2b
- type Charinfo
- type CirculateNotifyEvent
- type CirculateRequestEvent
- type ClientMessageData
- type ClientMessageEvent
- type Coloritem
- type ColormapNotifyEvent
- type ConfigureNotifyEvent
- type ConfigureRequestEvent
- type Conn
- func (c *Conn) AllocColor(Cmap Id, Red uint16, Green uint16, Blue uint16) (*AllocColorReply, error)
- func (c *Conn) AllocColorCells(Contiguous bool, Cmap Id, Colors uint16, Planes uint16) (*AllocColorCellsReply, error)
- func (c *Conn) AllocColorCellsReply(cookie Cookie) (*AllocColorCellsReply, error)
- func (c *Conn) AllocColorCellsRequest(Contiguous bool, Cmap Id, Colors uint16, Planes uint16) Cookie
- func (c *Conn) AllocColorPlanes(Contiguous bool, Cmap Id, Colors uint16, Reds uint16, Greens uint16, ...) (*AllocColorPlanesReply, error)
- func (c *Conn) AllocColorPlanesReply(cookie Cookie) (*AllocColorPlanesReply, error)
- func (c *Conn) AllocColorPlanesRequest(Contiguous bool, Cmap Id, Colors uint16, Reds uint16, Greens uint16, ...) Cookie
- func (c *Conn) AllocColorReply(cookie Cookie) (*AllocColorReply, error)
- func (c *Conn) AllocColorRequest(Cmap Id, Red uint16, Green uint16, Blue uint16) Cookie
- func (c *Conn) AllocNamedColor(Cmap Id, Name string) (*AllocNamedColorReply, error)
- func (c *Conn) AllocNamedColorReply(cookie Cookie) (*AllocNamedColorReply, error)
- func (c *Conn) AllocNamedColorRequest(Cmap Id, Name string) Cookie
- func (c *Conn) AllowEvents(Mode byte, Time Timestamp)
- func (c *Conn) Bell(Percent int8)
- func (c *Conn) ChangeActivePointerGrab(Cursor Id, Time Timestamp, EventMask uint16)
- func (c *Conn) ChangeGC(Gc Id, ValueMask uint32, ValueList []uint32)
- func (c *Conn) ChangeHosts(Mode byte, Family byte, Address []byte)
- func (c *Conn) ChangeKeyboardControl(ValueMask uint32, ValueList []uint32)
- func (c *Conn) ChangeKeyboardMapping(KeycodeCount byte, FirstKeycode byte, KeysymsPerKeycode byte, Keysyms []Keysym)
- func (c *Conn) ChangePointerControl(AccelerationNumerator int16, AccelerationDenominator int16, Threshold int16, ...)
- func (c *Conn) ChangeProperty(Mode byte, Window Id, Property Id, Type Id, Format byte, Data []byte)
- func (c *Conn) ChangeSaveSet(Mode byte, Window Id)
- func (c *Conn) ChangeWindowAttributes(Window Id, ValueMask uint32, ValueList []uint32)
- func (c *Conn) CirculateWindow(Direction byte, Window Id)
- func (c *Conn) ClearArea(Exposures bool, Window Id, X int16, Y int16, Width uint16, Height uint16)
- func (c *Conn) Close()
- func (c *Conn) CloseFont(Font Id)
- func (c *Conn) ConfigureWindow(Window Id, ValueMask uint16, ValueList []uint32)
- func (c *Conn) ConvertSelection(Requestor Id, Selection Id, Target Id, Property Id, Time Timestamp)
- func (c *Conn) CopyArea(SrcDrawable Id, DstDrawable Id, Gc Id, SrcX int16, SrcY int16, DstX int16, ...)
- func (c *Conn) CopyColormapAndFree(Mid Id, SrcCmap Id)
- func (c *Conn) CopyGC(SrcGc Id, DstGc Id, ValueMask uint32)
- func (c *Conn) CopyPlane(SrcDrawable Id, DstDrawable Id, Gc Id, SrcX int16, SrcY int16, DstX int16, ...)
- func (c *Conn) CreateColormap(Alloc byte, Mid Id, Window Id, Visual Id)
- func (c *Conn) CreateCursor(Cid Id, Source Id, Mask Id, ForeRed uint16, ForeGreen uint16, ForeBlue uint16, ...)
- func (c *Conn) CreateGC(Cid Id, Drawable Id, ValueMask uint32, ValueList []uint32)
- func (c *Conn) CreateGlyphCursor(Cid Id, SourceFont Id, MaskFont Id, SourceChar uint16, MaskChar uint16, ...)
- func (c *Conn) CreatePixmap(Depth byte, Pid Id, Drawable Id, Width uint16, Height uint16)
- func (c *Conn) CreateWindow(Depth byte, Wid Id, Parent Id, X int16, Y int16, Width uint16, Height uint16, ...)
- func (c *Conn) DefaultScreen() *ScreenInfo
- func (c *Conn) DeleteProperty(Window Id, Property Id)
- func (c *Conn) DestroySubwindows(Window Id)
- func (c *Conn) DestroyWindow(Window Id)
- func (c *Conn) FillPoly(Drawable Id, Gc Id, Shape byte, CoordinateMode byte, Points []Point)
- func (c *Conn) ForceScreenSaver(Mode byte)
- func (c *Conn) FreeColormap(Cmap Id)
- func (c *Conn) FreeColors(Cmap Id, PlaneMask uint32, Pixels []uint32)
- func (c *Conn) FreeCursor(Cursor Id)
- func (c *Conn) FreeGC(Gc Id)
- func (c *Conn) FreePixmap(Pixmap Id)
- func (c *Conn) GetAtomName(Atom Id) (*GetAtomNameReply, error)
- func (c *Conn) GetAtomNameReply(cookie Cookie) (*GetAtomNameReply, error)
- func (c *Conn) GetAtomNameRequest(Atom Id) Cookie
- func (c *Conn) GetFontPath() (*GetFontPathReply, error)
- func (c *Conn) GetFontPathReply(cookie Cookie) (*GetFontPathReply, error)
- func (c *Conn) GetFontPathRequest() Cookie
- func (c *Conn) GetGeometry(Drawable Id) (*GetGeometryReply, error)
- func (c *Conn) GetGeometryReply(cookie Cookie) (*GetGeometryReply, error)
- func (c *Conn) GetGeometryRequest(Drawable Id) Cookie
- func (c *Conn) GetImage(Format byte, Drawable Id, X int16, Y int16, Width uint16, Height uint16, ...) (*GetImageReply, error)
- func (c *Conn) GetImageReply(cookie Cookie) (*GetImageReply, error)
- func (c *Conn) GetImageRequest(Format byte, Drawable Id, X int16, Y int16, Width uint16, Height uint16, ...) Cookie
- func (c *Conn) GetInputFocus() (*GetInputFocusReply, error)
- func (c *Conn) GetInputFocusReply(cookie Cookie) (*GetInputFocusReply, error)
- func (c *Conn) GetInputFocusRequest() Cookie
- func (c *Conn) GetKeyboardControl() (*GetKeyboardControlReply, error)
- func (c *Conn) GetKeyboardControlReply(cookie Cookie) (*GetKeyboardControlReply, error)
- func (c *Conn) GetKeyboardControlRequest() Cookie
- func (c *Conn) GetKeyboardMapping(FirstKeycode byte, Count byte) (*GetKeyboardMappingReply, error)
- func (c *Conn) GetKeyboardMappingReply(cookie Cookie) (*GetKeyboardMappingReply, error)
- func (c *Conn) GetKeyboardMappingRequest(FirstKeycode byte, Count byte) Cookie
- func (c *Conn) GetModifierMapping() (*GetModifierMappingReply, error)
- func (c *Conn) GetModifierMappingReply(cookie Cookie) (*GetModifierMappingReply, error)
- func (c *Conn) GetModifierMappingRequest() Cookie
- func (c *Conn) GetMotionEvents(Window Id, Start Timestamp, Stop Timestamp) (*GetMotionEventsReply, error)
- func (c *Conn) GetMotionEventsReply(cookie Cookie) (*GetMotionEventsReply, error)
- func (c *Conn) GetMotionEventsRequest(Window Id, Start Timestamp, Stop Timestamp) Cookie
- func (c *Conn) GetPointerControl() (*GetPointerControlReply, error)
- func (c *Conn) GetPointerControlReply(cookie Cookie) (*GetPointerControlReply, error)
- func (c *Conn) GetPointerControlRequest() Cookie
- func (c *Conn) GetPointerMapping() (*GetPointerMappingReply, error)
- func (c *Conn) GetPointerMappingReply(cookie Cookie) (*GetPointerMappingReply, error)
- func (c *Conn) GetPointerMappingRequest() Cookie
- func (c *Conn) GetProperty(Delete bool, Window Id, Property Id, Type Id, LongOffset uint32, ...) (*GetPropertyReply, error)
- func (c *Conn) GetPropertyReply(cookie Cookie) (*GetPropertyReply, error)
- func (c *Conn) GetPropertyRequest(Delete bool, Window Id, Property Id, Type Id, LongOffset uint32, ...) Cookie
- func (c *Conn) GetScreenSaver() (*GetScreenSaverReply, error)
- func (c *Conn) GetScreenSaverReply(cookie Cookie) (*GetScreenSaverReply, error)
- func (c *Conn) GetScreenSaverRequest() Cookie
- func (c *Conn) GetSelectionOwner(Selection Id) (*GetSelectionOwnerReply, error)
- func (c *Conn) GetSelectionOwnerReply(cookie Cookie) (*GetSelectionOwnerReply, error)
- func (c *Conn) GetSelectionOwnerRequest(Selection Id) Cookie
- func (c *Conn) GetWindowAttributes(Window Id) (*GetWindowAttributesReply, error)
- func (c *Conn) GetWindowAttributesReply(cookie Cookie) (*GetWindowAttributesReply, error)
- func (c *Conn) GetWindowAttributesRequest(Window Id) Cookie
- func (c *Conn) GrabButton(OwnerEvents bool, GrabWindow Id, EventMask uint16, PointerMode byte, ...)
- func (c *Conn) GrabKey(OwnerEvents bool, GrabWindow Id, Modifiers uint16, Key byte, PointerMode byte, ...)
- func (c *Conn) GrabKeyboard(OwnerEvents bool, GrabWindow Id, Time Timestamp, PointerMode byte, ...) (*GrabKeyboardReply, error)
- func (c *Conn) GrabKeyboardReply(cookie Cookie) (*GrabKeyboardReply, error)
- func (c *Conn) GrabKeyboardRequest(OwnerEvents bool, GrabWindow Id, Time Timestamp, PointerMode byte, ...) Cookie
- func (c *Conn) GrabPointer(OwnerEvents bool, GrabWindow Id, EventMask uint16, PointerMode byte, ...) (*GrabPointerReply, error)
- func (c *Conn) GrabPointerReply(cookie Cookie) (*GrabPointerReply, error)
- func (c *Conn) GrabPointerRequest(OwnerEvents bool, GrabWindow Id, EventMask uint16, PointerMode byte, ...) Cookie
- func (c *Conn) GrabServer()
- func (c *Conn) ImageText16(Drawable Id, Gc Id, X int16, Y int16, String []Char2b)
- func (c *Conn) ImageText8(Drawable Id, Gc Id, X int16, Y int16, String []byte)
- func (c *Conn) InstallColormap(Cmap Id)
- func (c *Conn) InternAtom(OnlyIfExists bool, Name string) (*InternAtomReply, error)
- func (c *Conn) InternAtomReply(cookie Cookie) (*InternAtomReply, error)
- func (c *Conn) InternAtomRequest(OnlyIfExists bool, Name string) Cookie
- func (c *Conn) KillClient(Resource uint32)
- func (c *Conn) ListExtensions() (*ListExtensionsReply, error)
- func (c *Conn) ListExtensionsReply(cookie Cookie) (*ListExtensionsReply, error)
- func (c *Conn) ListExtensionsRequest() Cookie
- func (c *Conn) ListFonts(MaxNames uint16, Pattern []byte) (*ListFontsReply, error)
- func (c *Conn) ListFontsReply(cookie Cookie) (*ListFontsReply, error)
- func (c *Conn) ListFontsRequest(MaxNames uint16, Pattern []byte) Cookie
- func (c *Conn) ListFontsWithInfo(MaxNames uint16, Pattern []byte) (*ListFontsWithInfoReply, error)
- func (c *Conn) ListFontsWithInfoReply(cookie Cookie) (*ListFontsWithInfoReply, error)
- func (c *Conn) ListFontsWithInfoRequest(MaxNames uint16, Pattern []byte) Cookie
- func (c *Conn) ListHosts() (*ListHostsReply, error)
- func (c *Conn) ListHostsReply(cookie Cookie) (*ListHostsReply, error)
- func (c *Conn) ListHostsRequest() Cookie
- func (c *Conn) ListInstalledColormaps(Window Id) (*ListInstalledColormapsReply, error)
- func (c *Conn) ListInstalledColormapsReply(cookie Cookie) (*ListInstalledColormapsReply, error)
- func (c *Conn) ListInstalledColormapsRequest(Window Id) Cookie
- func (c *Conn) ListProperties(Window Id) (*ListPropertiesReply, error)
- func (c *Conn) ListPropertiesReply(cookie Cookie) (*ListPropertiesReply, error)
- func (c *Conn) ListPropertiesRequest(Window Id) Cookie
- func (c *Conn) LookupColor(Cmap Id, Name string) (*LookupColorReply, error)
- func (c *Conn) LookupColorReply(cookie Cookie) (*LookupColorReply, error)
- func (c *Conn) LookupColorRequest(Cmap Id, Name string) Cookie
- func (c *Conn) MapSubwindows(Window Id)
- func (c *Conn) MapWindow(Window Id)
- func (c *Conn) NewId() Id
- func (c *Conn) NoOperation()
- func (c *Conn) OpenFont(Fid Id, Name string)
- func (c *Conn) PollForEvent() (Event, error)
- func (c *Conn) PolyArc(Drawable Id, Gc Id, Arcs []Arc)
- func (c *Conn) PolyFillArc(Drawable Id, Gc Id, Arcs []Arc)
- func (c *Conn) PolyFillRectangle(Drawable Id, Gc Id, Rectangles []Rectangle)
- func (c *Conn) PolyLine(CoordinateMode byte, Drawable Id, Gc Id, Points []Point)
- func (c *Conn) PolyPoint(CoordinateMode byte, Drawable Id, Gc Id, Points []Point)
- func (c *Conn) PolyRectangle(Drawable Id, Gc Id, Rectangles []Rectangle)
- func (c *Conn) PolySegment(Drawable Id, Gc Id, Segments []Segment)
- func (c *Conn) PolyText16(Drawable Id, Gc Id, X int16, Y int16, Items []byte)
- func (c *Conn) PolyText8(Drawable Id, Gc Id, X int16, Y int16, Items []byte)
- func (c *Conn) PutImage(Format byte, Drawable Id, Gc Id, Width uint16, Height uint16, DstX int16, ...)
- func (c *Conn) QueryBestSize(Class byte, Drawable Id, Width uint16, Height uint16) (*QueryBestSizeReply, error)
- func (c *Conn) QueryBestSizeReply(cookie Cookie) (*QueryBestSizeReply, error)
- func (c *Conn) QueryBestSizeRequest(Class byte, Drawable Id, Width uint16, Height uint16) Cookie
- func (c *Conn) QueryColors(Cmap Id, Pixels []uint32) (*QueryColorsReply, error)
- func (c *Conn) QueryColorsReply(cookie Cookie) (*QueryColorsReply, error)
- func (c *Conn) QueryColorsRequest(Cmap Id, Pixels []uint32) Cookie
- func (c *Conn) QueryExtension(Name string) (*QueryExtensionReply, error)
- func (c *Conn) QueryExtensionReply(cookie Cookie) (*QueryExtensionReply, error)
- func (c *Conn) QueryExtensionRequest(Name string) Cookie
- func (c *Conn) QueryFont(Font Id) (*QueryFontReply, error)
- func (c *Conn) QueryFontReply(cookie Cookie) (*QueryFontReply, error)
- func (c *Conn) QueryFontRequest(Font Id) Cookie
- func (c *Conn) QueryKeymap() (*QueryKeymapReply, error)
- func (c *Conn) QueryKeymapReply(cookie Cookie) (*QueryKeymapReply, error)
- func (c *Conn) QueryKeymapRequest() Cookie
- func (c *Conn) QueryPointer(Window Id) (*QueryPointerReply, error)
- func (c *Conn) QueryPointerReply(cookie Cookie) (*QueryPointerReply, error)
- func (c *Conn) QueryPointerRequest(Window Id) Cookie
- func (c *Conn) QueryTextExtents(Font Id, String []Char2b) (*QueryTextExtentsReply, error)
- func (c *Conn) QueryTextExtentsReply(cookie Cookie) (*QueryTextExtentsReply, error)
- func (c *Conn) QueryTextExtentsRequest(Font Id, String []Char2b) Cookie
- func (c *Conn) QueryTree(Window Id) (*QueryTreeReply, error)
- func (c *Conn) QueryTreeReply(cookie Cookie) (*QueryTreeReply, error)
- func (c *Conn) QueryTreeRequest(Window Id) Cookie
- func (c *Conn) RecolorCursor(Cursor Id, ForeRed uint16, ForeGreen uint16, ForeBlue uint16, BackRed uint16, ...)
- func (c *Conn) ReparentWindow(Window Id, Parent Id, X int16, Y int16)
- func (c *Conn) RotateProperties(Window Id, Delta int16, Atoms []Id)
- func (c *Conn) SendEvent(Propagate bool, Destination Id, EventMask uint32, Event []byte)
- func (c *Conn) SetAccessControl(Mode byte)
- func (c *Conn) SetClipRectangles(Ordering byte, Gc Id, ClipXOrigin int16, ClipYOrigin int16, ...)
- func (c *Conn) SetCloseDownMode(Mode byte)
- func (c *Conn) SetDashes(Gc Id, DashOffset uint16, Dashes []byte)
- func (c *Conn) SetFontPath(FontQty uint16, Path []byte)
- func (c *Conn) SetInputFocus(RevertTo byte, Focus Id, Time Timestamp)
- func (c *Conn) SetModifierMapping(KeycodesPerModifier byte, Keycodes []byte) (*SetModifierMappingReply, error)
- func (c *Conn) SetModifierMappingReply(cookie Cookie) (*SetModifierMappingReply, error)
- func (c *Conn) SetModifierMappingRequest(KeycodesPerModifier byte, Keycodes []byte) Cookie
- func (c *Conn) SetPointerMapping(Map []byte) (*SetPointerMappingReply, error)
- func (c *Conn) SetPointerMappingReply(cookie Cookie) (*SetPointerMappingReply, error)
- func (c *Conn) SetPointerMappingRequest(Map []byte) Cookie
- func (c *Conn) SetScreenSaver(Timeout int16, Interval int16, PreferBlanking byte, AllowExposures byte)
- func (c *Conn) SetSelectionOwner(Owner Id, Selection Id, Time Timestamp)
- func (c *Conn) StoreColors(Cmap Id, Items []Coloritem)
- func (c *Conn) StoreNamedColor(Flags byte, Cmap Id, Pixel uint32, Name string)
- func (c *Conn) TranslateCoordinates(SrcWindow Id, DstWindow Id, SrcX int16, SrcY int16) (*TranslateCoordinatesReply, error)
- func (c *Conn) TranslateCoordinatesReply(cookie Cookie) (*TranslateCoordinatesReply, error)
- func (c *Conn) TranslateCoordinatesRequest(SrcWindow Id, DstWindow Id, SrcX int16, SrcY int16) Cookie
- func (c *Conn) UngrabButton(Button byte, GrabWindow Id, Modifiers uint16)
- func (c *Conn) UngrabKey(Key byte, GrabWindow Id, Modifiers uint16)
- func (c *Conn) UngrabKeyboard(Time Timestamp)
- func (c *Conn) UngrabPointer(Time Timestamp)
- func (c *Conn) UngrabServer()
- func (c *Conn) UninstallColormap(Cmap Id)
- func (c *Conn) UnmapSubwindows(Window Id)
- func (c *Conn) UnmapWindow(Window Id)
- func (c *Conn) WaitForEvent() (Event, error)
- func (c *Conn) WarpPointer(SrcWindow Id, DstWindow Id, SrcX int16, SrcY int16, SrcWidth uint16, ...)
- type Cookie
- type CreateNotifyEvent
- type DepthInfo
- type DestroyNotifyEvent
- type EnterNotifyEvent
- type Error
- type Event
- type ExposeEvent
- type FocusInEvent
- type FocusOutEvent
- type Fontprop
- type Format
- type GetAtomNameReply
- type GetFontPathReply
- type GetGeometryReply
- type GetImageReply
- type GetInputFocusReply
- type GetKeyboardControlReply
- type GetKeyboardMappingReply
- type GetModifierMappingReply
- type GetMotionEventsReply
- type GetPointerControlReply
- type GetPointerMappingReply
- type GetPropertyReply
- type GetScreenSaverReply
- type GetSelectionOwnerReply
- type GetWindowAttributesReply
- type GrabKeyboardReply
- type GrabPointerReply
- type GraphicsExposureEvent
- type GravityNotifyEvent
- type Host
- type Id
- type InternAtomReply
- type KeyPressEvent
- type KeyReleaseEvent
- type KeymapNotifyEvent
- type Keysym
- type LeaveNotifyEvent
- type ListExtensionsReply
- type ListFontsReply
- type ListFontsWithInfoReply
- type ListHostsReply
- type ListInstalledColormapsReply
- type ListPropertiesReply
- type LookupColorReply
- type MapNotifyEvent
- type MapRequestEvent
- type MappingNotifyEvent
- type MotionNotifyEvent
- type NoExposureEvent
- type Point
- type PropertyNotifyEvent
- type QueryBestSizeReply
- type QueryColorsReply
- type QueryExtensionReply
- type QueryFontReply
- type QueryKeymapReply
- type QueryPointerReply
- type QueryTextExtentsReply
- type QueryTreeReply
- type Rectangle
- type ReparentNotifyEvent
- type ResizeRequestEvent
- type Rgb
- type ScreenInfo
- type Segment
- type SelectionClearEvent
- type SelectionNotifyEvent
- type SelectionRequestEvent
- type SetModifierMappingReply
- type SetPointerMappingReply
- type SetupInfo
- type Str
- type Timecoord
- type Timestamp
- type TranslateCoordinatesReply
- type UnmapNotifyEvent
- type VisibilityNotifyEvent
- type VisualInfo
Constants ¶
const ( VisualClassStaticGray = 0 VisualClassGrayScale = 1 VisualClassStaticColor = 2 VisualClassPseudoColor = 3 VisualClassTrueColor = 4 VisualClassDirectColor = 5 )
const ( EventMaskNoEvent = 0 EventMaskKeyPress = 1 EventMaskKeyRelease = 2 EventMaskButtonPress = 4 EventMaskButtonRelease = 8 EventMaskEnterWindow = 16 EventMaskLeaveWindow = 32 EventMaskPointerMotion = 64 EventMaskPointerMotionHint = 128 EventMaskButton1Motion = 256 EventMaskButton2Motion = 512 EventMaskButton3Motion = 1024 EventMaskButton4Motion = 2048 EventMaskButton5Motion = 4096 EventMaskButtonMotion = 8192 EventMaskKeymapState = 16384 EventMaskExposure = 32768 EventMaskVisibilityChange = 65536 EventMaskStructureNotify = 131072 EventMaskResizeRedirect = 262144 EventMaskSubstructureNotify = 524288 EventMaskSubstructureRedirect = 1048576 EventMaskFocusChange = 2097152 EventMaskPropertyChange = 4194304 EventMaskColorMapChange = 8388608 EventMaskOwnerGrabButton = 16777216 )
const ( BackingStoreNotUseful = 0 BackingStoreWhenMapped = 1 BackingStoreAlways = 2 )
const ( ImageOrderLSBFirst = 0 ImageOrderMSBFirst = 1 )
const ( ModMaskShift = 1 ModMaskLock = 2 ModMaskControl = 4 ModMask1 = 8 ModMask2 = 16 ModMask3 = 32 ModMask4 = 64 ModMask5 = 128 ModMaskAny = 32768 )
const ( KeyButMaskShift = 1 KeyButMaskLock = 2 KeyButMaskControl = 4 KeyButMaskMod1 = 8 KeyButMaskMod2 = 16 KeyButMaskMod3 = 32 KeyButMaskMod4 = 64 KeyButMaskMod5 = 128 KeyButMaskButton1 = 256 KeyButMaskButton2 = 512 KeyButMaskButton3 = 1024 KeyButMaskButton4 = 2048 KeyButMaskButton5 = 4096 )
const ( ButtonMask1 = 256 ButtonMask2 = 512 ButtonMask3 = 1024 ButtonMask4 = 2048 ButtonMask5 = 4096 ButtonMaskAny = 32768 )
const ( MotionNormal = 0 MotionHint = 1 )
const ( NotifyDetailAncestor = 0 NotifyDetailVirtual = 1 NotifyDetailInferior = 2 NotifyDetailNonlinear = 3 NotifyDetailNonlinearVirtual = 4 NotifyDetailPointer = 5 NotifyDetailPointerRoot = 6 NotifyDetailNone = 7 )
const ( NotifyModeNormal = 0 NotifyModeGrab = 1 NotifyModeUngrab = 2 NotifyModeWhileGrabbed = 3 )
const ( VisibilityUnobscured = 0 VisibilityPartiallyObscured = 1 VisibilityFullyObscured = 2 )
const ( PlaceOnTop = 0 PlaceOnBottom = 1 )
const ( PropertyNewValue = 0 PropertyDelete = 1 )
const ( AtomNone = 0 AtomAny = 0 AtomPrimary = 1 AtomSecondary = 2 AtomArc = 3 AtomAtom = 4 AtomBitmap = 5 AtomCardinal = 6 AtomColormap = 7 AtomCursor = 8 AtomCutBuffer0 = 9 AtomCutBuffer1 = 10 AtomCutBuffer2 = 11 AtomCutBuffer3 = 12 AtomCutBuffer4 = 13 AtomCutBuffer5 = 14 AtomCutBuffer6 = 15 AtomCutBuffer7 = 16 AtomDrawable = 17 AtomFont = 18 AtomInteger = 19 AtomPixmap = 20 AtomPoint = 21 AtomRectangle = 22 AtomResourceManager = 23 AtomRgbColorMap = 24 AtomRgbBestMap = 25 AtomRgbBlueMap = 26 AtomRgbDefaultMap = 27 AtomRgbGrayMap = 28 AtomRgbGreenMap = 29 AtomRgbRedMap = 30 AtomString = 31 AtomVisualid = 32 AtomWindow = 33 AtomWmCommand = 34 AtomWmHints = 35 AtomWmClientMachine = 36 AtomWmIconName = 37 AtomWmIconSize = 38 AtomWmName = 39 AtomWmNormalHints = 40 AtomWmSizeHints = 41 AtomWmZoomHints = 42 AtomMinSpace = 43 AtomNormSpace = 44 AtomMaxSpace = 45 AtomEndSpace = 46 AtomSuperscriptX = 47 AtomSuperscriptY = 48 AtomSubscriptX = 49 AtomSubscriptY = 50 AtomUnderlinePosition = 51 AtomUnderlineThickness = 52 AtomStrikeoutAscent = 53 AtomStrikeoutDescent = 54 AtomItalicAngle = 55 AtomXHeight = 56 AtomQuadWidth = 57 AtomWeight = 58 AtomPointSize = 59 AtomResolution = 60 AtomCopyright = 61 AtomNotice = 62 AtomFontName = 63 AtomFamilyName = 64 AtomFullName = 65 AtomCapHeight = 66 AtomWmClass = 67 AtomWmTransientFor = 68 )
const ( ColormapStateUninstalled = 0 ColormapStateInstalled = 1 )
const ( MappingModifier = 0 MappingKeyboard = 1 MappingPointer = 2 )
const ( WindowClassCopyFromParent = 0 WindowClassInputOutput = 1 WindowClassInputOnly = 2 )
const ( CWBackPixmap = 1 CWBackPixel = 2 CWBorderPixmap = 4 CWBorderPixel = 8 CWBitGravity = 16 CWWinGravity = 32 CWBackingStore = 64 CWBackingPlanes = 128 CWBackingPixel = 256 CWOverrideRedirect = 512 CWSaveUnder = 1024 CWEventMask = 2048 CWDontPropagate = 4096 CWColormap = 8192 CWCursor = 16384 )
const ( BackPixmapNone = 0 BackPixmapParentRelative = 1 )
const ( GravityBitForget = 0 GravityWinUnmap = 0 GravityNorthWest = 1 GravityNorth = 2 GravityNorthEast = 3 GravityWest = 4 GravityCenter = 5 GravityEast = 6 GravitySouthWest = 7 GravitySouth = 8 GravitySouthEast = 9 GravityStatic = 10 )
const ( MapStateUnmapped = 0 MapStateUnviewable = 1 MapStateViewable = 2 )
const ( SetModeInsert = 0 SetModeDelete = 1 )
const ( ConfigWindowX = 1 ConfigWindowY = 2 ConfigWindowWidth = 4 ConfigWindowHeight = 8 ConfigWindowBorderWidth = 16 ConfigWindowSibling = 32 ConfigWindowStackMode = 64 )
const ( StackModeAbove = 0 StackModeBelow = 1 StackModeTopIf = 2 StackModeBottomIf = 3 StackModeOpposite = 4 )
const ( CirculateRaiseLowest = 0 CirculateLowerHighest = 1 )
const ( PropModeReplace = 0 PropModePrepend = 1 PropModeAppend = 2 )
const ( SendEventDestPointerWindow = 0 SendEventDestItemFocus = 1 )
const ( GrabModeSync = 0 GrabModeAsync = 1 )
const ( GrabStatusSuccess = 0 GrabStatusAlreadyGrabbed = 1 GrabStatusInvalidTime = 2 GrabStatusNotViewable = 3 GrabStatusFrozen = 4 )
const ( ButtonIndexAny = 0 ButtonIndex1 = 1 ButtonIndex2 = 2 ButtonIndex3 = 3 ButtonIndex4 = 4 ButtonIndex5 = 5 )
const ( AllowAsyncPointer = 0 AllowSyncPointer = 1 AllowReplayPointer = 2 AllowAsyncKeyboard = 3 AllowSyncKeyboard = 4 AllowReplayKeyboard = 5 AllowAsyncBoth = 6 AllowSyncBoth = 7 )
const ( InputFocusNone = 0 InputFocusPointerRoot = 1 InputFocusParent = 2 InputFocusFollowKeyboard = 3 )
const ( FontDrawLeftToRight = 0 FontDrawRightToLeft = 1 )
const ( GCFunction = 1 GCPlaneMask = 2 GCForeground = 4 GCBackground = 8 GCLineWidth = 16 GCLineStyle = 32 GCCapStyle = 64 GCJoinStyle = 128 GCFillStyle = 256 GCFillRule = 512 GCTile = 1024 GCStipple = 2048 GCTileStippleOriginX = 4096 GCTileStippleOriginY = 8192 GCFont = 16384 GCSubwindowMode = 32768 GCGraphicsExposures = 65536 GCClipOriginX = 131072 GCClipOriginY = 262144 GCClipMask = 524288 GCDashOffset = 1048576 GCDashList = 2097152 GCArcMode = 4194304 )
const ( GXClear = 0 GXAnd = 1 GXAndReverse = 2 GXCopy = 3 GXAndInverted = 4 GXNoop = 5 GXXor = 6 GXOr = 7 GXNor = 8 GXEquiv = 9 GXInvert = 10 GXOrReverse = 11 GXCopyInverted = 12 GXOrInverted = 13 GXNand = 14 GXSet = 15 )
const ( LineStyleSolid = 0 LineStyleOnOffDash = 1 LineStyleDoubleDash = 2 )
const ( CapStyleNotLast = 0 CapStyleButt = 1 CapStyleRound = 2 CapStyleProjecting = 3 )
const ( JoinStyleMiter = 0 JoinStyleRound = 1 JoinStyleBevel = 2 )
const ( FillStyleSolid = 0 FillStyleTiled = 1 FillStyleStippled = 2 FillStyleOpaqueStippled = 3 )
const ( FillRuleEvenOdd = 0 FillRuleWinding = 1 )
const ( SubwindowModeClipByChildren = 0 SubwindowModeIncludeInferiors = 1 )
const ( ArcModeChord = 0 ArcModePieSlice = 1 )
const ( ClipOrderingUnsorted = 0 ClipOrderingYSorted = 1 ClipOrderingYXSorted = 2 ClipOrderingYXBanded = 3 )
const ( CoordModeOrigin = 0 CoordModePrevious = 1 )
const ( PolyShapeComplex = 0 PolyShapeNonconvex = 1 PolyShapeConvex = 2 )
const ( ImageFormatXYBitmap = 0 ImageFormatXYPixmap = 1 ImageFormatZPixmap = 2 )
const ( ColormapAllocNone = 0 ColormapAllocAll = 1 )
const ( ColorFlagRed = 1 ColorFlagGreen = 2 ColorFlagBlue = 4 )
const ( QueryShapeOfLargestCursor = 0 QueryShapeOfFastestTile = 1 QueryShapeOfFastestStipple = 2 )
const ( KBKeyClickPercent = 1 KBBellPercent = 2 KBBellPitch = 4 KBBellDuration = 8 KBLed = 16 KBLedMode = 32 KBKey = 64 KBAutoRepeatMode = 128 )
const ( LedModeOff = 0 LedModeOn = 1 )
const ( AutoRepeatModeOff = 0 AutoRepeatModeOn = 1 AutoRepeatModeDefault = 2 )
const ( BlankingNotPreferred = 0 BlankingPreferred = 1 BlankingDefault = 2 )
const ( ExposuresNotAllowed = 0 ExposuresAllowed = 1 ExposuresDefault = 2 )
const ( HostModeInsert = 0 HostModeDelete = 1 )
const ( FamilyInternet = 0 FamilyDECnet = 1 FamilyChaos = 2 FamilyServerInterpreted = 5 FamilyInternet6 = 6 )
const ( AccessControlDisable = 0 AccessControlEnable = 1 )
const ( CloseDownDestroyAll = 0 CloseDownRetainPermanent = 1 CloseDownRetainTemporary = 2 )
const ( ScreenSaverReset = 0 ScreenSaverActive = 1 )
const ( MappingStatusSuccess = 0 MappingStatusBusy = 1 MappingStatusFailure = 2 )
const ( MapIndexShift = 0 MapIndexLock = 1 MapIndexControl = 2 MapIndex1 = 3 MapIndex2 = 4 MapIndex3 = 5 MapIndex4 = 6 MapIndex5 = 7 )
const BadAccess = 10
const BadAlloc = 11
const BadAtom = 5
const BadColormap = 12
const BadCursor = 6
const BadDrawable = 9
const BadFont = 7
const BadGContext = 13
const BadIDChoice = 14
const BadImplementation = 17
const BadLength = 16
const BadMatch = 8
const BadName = 15
const BadPixmap = 4
const BadRequest = 1
const BadValue = 2
const BadWindow = 3
const ButtonPress = 4
const ButtonRelease = 5
const CirculateNotify = 26
const CirculateRequest = 27
const ClientMessage = 33
const (
ColormapNone = 0
)
const ColormapNotify = 32
const ConfigureNotify = 22
const ConfigureRequest = 23
const CreateNotify = 16
const (
CursorNone = 0
)
const DestroyNotify = 17
const EnterNotify = 7
const Expose = 12
const FocusIn = 9
const FocusOut = 10
const (
FontNone = 0
)
const (
GetPropertyTypeAny = 0
)
const (
GrabAny = 0
)
const GraphicsExposure = 13
const GravityNotify = 24
const KeyPress = 2
const KeyRelease = 3
const KeymapNotify = 11
const (
KillAllTemporary = 0
)
const LeaveNotify = 8
const MapNotify = 19
const MapRequest = 20
const MappingNotify = 34
const MotionNotify = 6
const NoExposure = 14
const OpcodeAllocColor = 84
const OpcodeAllocColorCells = 86
const OpcodeAllocColorPlanes = 87
const OpcodeAllocNamedColor = 85
const OpcodeAllowEvents = 35
const OpcodeBell = 104
const OpcodeChangeActivePointerGrab = 30
const OpcodeChangeGC = 56
const OpcodeChangeHosts = 109
const OpcodeChangeKeyboardControl = 102
const OpcodeChangeKeyboardMapping = 100
const OpcodeChangePointerControl = 105
const OpcodeChangeProperty = 18
const OpcodeChangeSaveSet = 6
const OpcodeChangeWindowAttributes = 2
const OpcodeCirculateWindow = 13
const OpcodeClearArea = 61
const OpcodeCloseFont = 46
const OpcodeConfigureWindow = 12
const OpcodeConvertSelection = 24
const OpcodeCopyArea = 62
const OpcodeCopyColormapAndFree = 80
const OpcodeCopyGC = 57
const OpcodeCopyPlane = 63
const OpcodeCreateColormap = 78
const OpcodeCreateCursor = 93
const OpcodeCreateGC = 55
const OpcodeCreateGlyphCursor = 94
const OpcodeCreatePixmap = 53
const OpcodeCreateWindow = 1
const OpcodeDeleteProperty = 19
const OpcodeDestroySubwindows = 5
const OpcodeDestroyWindow = 4
const OpcodeFillPoly = 69
const OpcodeForceScreenSaver = 115
const OpcodeFreeColormap = 79
const OpcodeFreeColors = 88
const OpcodeFreeCursor = 95
const OpcodeFreeGC = 60
const OpcodeFreePixmap = 54
const OpcodeGetAtomName = 17
const OpcodeGetFontPath = 52
const OpcodeGetGeometry = 14
const OpcodeGetImage = 73
const OpcodeGetInputFocus = 43
const OpcodeGetKeyboardControl = 103
const OpcodeGetKeyboardMapping = 101
const OpcodeGetModifierMapping = 119
const OpcodeGetMotionEvents = 39
const OpcodeGetPointerControl = 106
const OpcodeGetPointerMapping = 117
const OpcodeGetProperty = 20
const OpcodeGetScreenSaver = 108
const OpcodeGetSelectionOwner = 23
const OpcodeGetWindowAttributes = 3
const OpcodeGrabButton = 28
const OpcodeGrabKey = 33
const OpcodeGrabKeyboard = 31
const OpcodeGrabPointer = 26
const OpcodeGrabServer = 36
const OpcodeImageText16 = 77
const OpcodeImageText8 = 76
const OpcodeInstallColormap = 81
const OpcodeInternAtom = 16
const OpcodeKillClient = 113
const OpcodeListExtensions = 99
const OpcodeListFonts = 49
const OpcodeListFontsWithInfo = 50
const OpcodeListHosts = 110
const OpcodeListInstalledColormaps = 83
const OpcodeListProperties = 21
const OpcodeLookupColor = 92
const OpcodeMapSubwindows = 9
const OpcodeMapWindow = 8
const OpcodeNoOperation = 127
const OpcodeOpenFont = 45
const OpcodePolyArc = 68
const OpcodePolyFillArc = 71
const OpcodePolyFillRectangle = 70
const OpcodePolyLine = 65
const OpcodePolyPoint = 64
const OpcodePolyRectangle = 67
const OpcodePolySegment = 66
const OpcodePolyText16 = 75
const OpcodePolyText8 = 74
const OpcodePutImage = 72
const OpcodeQueryBestSize = 97
const OpcodeQueryColors = 91
const OpcodeQueryExtension = 98
const OpcodeQueryFont = 47
const OpcodeQueryKeymap = 44
const OpcodeQueryPointer = 38
const OpcodeQueryTextExtents = 48
const OpcodeQueryTree = 15
const OpcodeRecolorCursor = 96
const OpcodeReparentWindow = 7
const OpcodeRotateProperties = 114
const OpcodeSendEvent = 25
const OpcodeSetAccessControl = 111
const OpcodeSetClipRectangles = 59
const OpcodeSetCloseDownMode = 112
const OpcodeSetDashes = 58
const OpcodeSetFontPath = 51
const OpcodeSetInputFocus = 42
const OpcodeSetModifierMapping = 118
const OpcodeSetPointerMapping = 116
const OpcodeSetScreenSaver = 107
const OpcodeSetSelectionOwner = 22
const OpcodeStoreColors = 89
const OpcodeStoreNamedColor = 90
const OpcodeTranslateCoordinates = 40
const OpcodeUngrabButton = 29
const OpcodeUngrabKey = 34
const OpcodeUngrabKeyboard = 32
const OpcodeUngrabPointer = 27
const OpcodeUngrabServer = 37
const OpcodeUninstallColormap = 82
const OpcodeUnmapSubwindows = 11
const OpcodeUnmapWindow = 10
const OpcodeWarpPointer = 41
const (
PixmapNone = 0
)
const PropertyNotify = 28
const ReparentNotify = 21
const ResizeRequest = 25
const SelectionClear = 29
const SelectionNotify = 31
const SelectionRequest = 30
const (
TimeCurrentTime = 0
)
const UnmapNotify = 18
const VisibilityNotify = 15
const (
WindowNone = 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllocColorCellsReply ¶
type AllocColorPlanesReply ¶
type AllocColorReply ¶
type AllocNamedColorReply ¶
type ButtonPressEvent ¶
type ButtonReleaseEvent ¶
type ButtonReleaseEvent ButtonPressEvent
type CirculateNotifyEvent ¶
type CirculateRequestEvent ¶
type CirculateRequestEvent CirculateNotifyEvent
type ClientMessageData ¶
ClientMessageData holds the data from a client message, duplicated in three forms because Go doesn't have unions.
type ClientMessageEvent ¶
type ClientMessageEvent struct {
Format byte
Window Id
Type Id
Data ClientMessageData
}
type ColormapNotifyEvent ¶
type ConfigureNotifyEvent ¶
type ConfigureRequestEvent ¶
type Conn ¶
type Conn struct {
Setup SetupInfo
// contains filtered or unexported fields
}
A Conn represents a connection to an X server. Only one goroutine should use a Conn's methods at a time.
func Dial ¶
Dial connects to the X server given in the 'display' string. If 'display' is empty it will be taken from os.Getenv("DISPLAY").
Examples:
Dial(":1") // connect to net.Dial("unix", "", "/tmp/.X11-unix/X1")
Dial("/tmp/launch-123/:0") // connect to net.Dial("unix", "", "/tmp/launch-123/:0")
Dial("hostname:2.1") // connect to net.Dial("tcp", "", "hostname:6002")
Dial("tcp/hostname:1.0") // connect to net.Dial("tcp", "", "hostname:6001")
func (*Conn) AllocColor ¶
func (*Conn) AllocColorCells ¶
func (*Conn) AllocColorCellsReply ¶
func (c *Conn) AllocColorCellsReply(cookie Cookie) (*AllocColorCellsReply, error)
func (*Conn) AllocColorCellsRequest ¶
func (*Conn) AllocColorPlanes ¶
func (*Conn) AllocColorPlanesReply ¶
func (c *Conn) AllocColorPlanesReply(cookie Cookie) (*AllocColorPlanesReply, error)
func (*Conn) AllocColorPlanesRequest ¶
func (*Conn) AllocColorReply ¶
func (c *Conn) AllocColorReply(cookie Cookie) (*AllocColorReply, error)
func (*Conn) AllocColorRequest ¶
func (*Conn) AllocNamedColor ¶
func (c *Conn) AllocNamedColor(Cmap Id, Name string) (*AllocNamedColorReply, error)
func (*Conn) AllocNamedColorReply ¶
func (c *Conn) AllocNamedColorReply(cookie Cookie) (*AllocNamedColorReply, error)
func (*Conn) AllocNamedColorRequest ¶
func (*Conn) AllowEvents ¶
func (*Conn) ChangeActivePointerGrab ¶
func (*Conn) ChangeKeyboardControl ¶
func (*Conn) ChangeKeyboardMapping ¶
func (*Conn) ChangePointerControl ¶
func (*Conn) ChangeProperty ¶
func (*Conn) ChangeSaveSet ¶
func (*Conn) ChangeWindowAttributes ¶
func (*Conn) CirculateWindow ¶
func (*Conn) ConfigureWindow ¶
func (*Conn) ConvertSelection ¶
func (*Conn) CopyColormapAndFree ¶
func (*Conn) CreateColormap ¶
func (*Conn) CreateCursor ¶
func (*Conn) CreateGlyphCursor ¶
func (*Conn) CreatePixmap ¶
func (*Conn) CreateWindow ¶
func (*Conn) DefaultScreen ¶
func (c *Conn) DefaultScreen() *ScreenInfo
DefaultScreen returns the Screen info for the default screen, which is 0 or the one given in the display argument to Dial.
func (*Conn) DeleteProperty ¶
func (*Conn) DestroySubwindows ¶
func (*Conn) DestroyWindow ¶
func (*Conn) ForceScreenSaver ¶
func (*Conn) FreeColormap ¶
func (*Conn) FreeCursor ¶
func (*Conn) FreePixmap ¶
func (*Conn) GetAtomName ¶
func (c *Conn) GetAtomName(Atom Id) (*GetAtomNameReply, error)
func (*Conn) GetAtomNameReply ¶
func (c *Conn) GetAtomNameReply(cookie Cookie) (*GetAtomNameReply, error)
func (*Conn) GetAtomNameRequest ¶
func (*Conn) GetFontPath ¶
func (c *Conn) GetFontPath() (*GetFontPathReply, error)
func (*Conn) GetFontPathReply ¶
func (c *Conn) GetFontPathReply(cookie Cookie) (*GetFontPathReply, error)
func (*Conn) GetFontPathRequest ¶
func (*Conn) GetGeometry ¶
func (c *Conn) GetGeometry(Drawable Id) (*GetGeometryReply, error)
func (*Conn) GetGeometryReply ¶
func (c *Conn) GetGeometryReply(cookie Cookie) (*GetGeometryReply, error)
func (*Conn) GetGeometryRequest ¶
func (*Conn) GetImageReply ¶
func (c *Conn) GetImageReply(cookie Cookie) (*GetImageReply, error)
func (*Conn) GetImageRequest ¶
func (*Conn) GetInputFocus ¶
func (c *Conn) GetInputFocus() (*GetInputFocusReply, error)
func (*Conn) GetInputFocusReply ¶
func (c *Conn) GetInputFocusReply(cookie Cookie) (*GetInputFocusReply, error)
func (*Conn) GetInputFocusRequest ¶
func (*Conn) GetKeyboardControl ¶
func (c *Conn) GetKeyboardControl() (*GetKeyboardControlReply, error)
func (*Conn) GetKeyboardControlReply ¶
func (c *Conn) GetKeyboardControlReply(cookie Cookie) (*GetKeyboardControlReply, error)
func (*Conn) GetKeyboardControlRequest ¶
func (*Conn) GetKeyboardMapping ¶
func (c *Conn) GetKeyboardMapping(FirstKeycode byte, Count byte) (*GetKeyboardMappingReply, error)
func (*Conn) GetKeyboardMappingReply ¶
func (c *Conn) GetKeyboardMappingReply(cookie Cookie) (*GetKeyboardMappingReply, error)
func (*Conn) GetKeyboardMappingRequest ¶
func (*Conn) GetModifierMapping ¶
func (c *Conn) GetModifierMapping() (*GetModifierMappingReply, error)
func (*Conn) GetModifierMappingReply ¶
func (c *Conn) GetModifierMappingReply(cookie Cookie) (*GetModifierMappingReply, error)
func (*Conn) GetModifierMappingRequest ¶
func (*Conn) GetMotionEvents ¶
func (*Conn) GetMotionEventsReply ¶
func (c *Conn) GetMotionEventsReply(cookie Cookie) (*GetMotionEventsReply, error)
func (*Conn) GetMotionEventsRequest ¶
func (*Conn) GetPointerControl ¶
func (c *Conn) GetPointerControl() (*GetPointerControlReply, error)
func (*Conn) GetPointerControlReply ¶
func (c *Conn) GetPointerControlReply(cookie Cookie) (*GetPointerControlReply, error)
func (*Conn) GetPointerControlRequest ¶
func (*Conn) GetPointerMapping ¶
func (c *Conn) GetPointerMapping() (*GetPointerMappingReply, error)
func (*Conn) GetPointerMappingReply ¶
func (c *Conn) GetPointerMappingReply(cookie Cookie) (*GetPointerMappingReply, error)
func (*Conn) GetPointerMappingRequest ¶
func (*Conn) GetProperty ¶
func (*Conn) GetPropertyReply ¶
func (c *Conn) GetPropertyReply(cookie Cookie) (*GetPropertyReply, error)
func (*Conn) GetPropertyRequest ¶
func (*Conn) GetScreenSaver ¶
func (c *Conn) GetScreenSaver() (*GetScreenSaverReply, error)
func (*Conn) GetScreenSaverReply ¶
func (c *Conn) GetScreenSaverReply(cookie Cookie) (*GetScreenSaverReply, error)
func (*Conn) GetScreenSaverRequest ¶
func (*Conn) GetSelectionOwner ¶
func (c *Conn) GetSelectionOwner(Selection Id) (*GetSelectionOwnerReply, error)
func (*Conn) GetSelectionOwnerReply ¶
func (c *Conn) GetSelectionOwnerReply(cookie Cookie) (*GetSelectionOwnerReply, error)
func (*Conn) GetSelectionOwnerRequest ¶
func (*Conn) GetWindowAttributes ¶
func (c *Conn) GetWindowAttributes(Window Id) (*GetWindowAttributesReply, error)
func (*Conn) GetWindowAttributesReply ¶
func (c *Conn) GetWindowAttributesReply(cookie Cookie) (*GetWindowAttributesReply, error)
func (*Conn) GetWindowAttributesRequest ¶
func (*Conn) GrabButton ¶
func (*Conn) GrabKeyboard ¶
func (*Conn) GrabKeyboardReply ¶
func (c *Conn) GrabKeyboardReply(cookie Cookie) (*GrabKeyboardReply, error)
func (*Conn) GrabKeyboardRequest ¶
func (*Conn) GrabPointer ¶
func (*Conn) GrabPointerReply ¶
func (c *Conn) GrabPointerReply(cookie Cookie) (*GrabPointerReply, error)
func (*Conn) GrabPointerRequest ¶
func (*Conn) GrabServer ¶
func (c *Conn) GrabServer()
func (*Conn) ImageText16 ¶
func (*Conn) ImageText8 ¶
func (*Conn) InstallColormap ¶
func (*Conn) InternAtom ¶
func (c *Conn) InternAtom(OnlyIfExists bool, Name string) (*InternAtomReply, error)
func (*Conn) InternAtomReply ¶
func (c *Conn) InternAtomReply(cookie Cookie) (*InternAtomReply, error)
func (*Conn) InternAtomRequest ¶
func (*Conn) KillClient ¶
func (*Conn) ListExtensions ¶
func (c *Conn) ListExtensions() (*ListExtensionsReply, error)
func (*Conn) ListExtensionsReply ¶
func (c *Conn) ListExtensionsReply(cookie Cookie) (*ListExtensionsReply, error)
func (*Conn) ListExtensionsRequest ¶
func (*Conn) ListFonts ¶
func (c *Conn) ListFonts(MaxNames uint16, Pattern []byte) (*ListFontsReply, error)
func (*Conn) ListFontsReply ¶
func (c *Conn) ListFontsReply(cookie Cookie) (*ListFontsReply, error)
func (*Conn) ListFontsRequest ¶
func (*Conn) ListFontsWithInfo ¶
func (c *Conn) ListFontsWithInfo(MaxNames uint16, Pattern []byte) (*ListFontsWithInfoReply, error)
func (*Conn) ListFontsWithInfoReply ¶
func (c *Conn) ListFontsWithInfoReply(cookie Cookie) (*ListFontsWithInfoReply, error)
func (*Conn) ListFontsWithInfoRequest ¶
func (*Conn) ListHosts ¶
func (c *Conn) ListHosts() (*ListHostsReply, error)
func (*Conn) ListHostsReply ¶
func (c *Conn) ListHostsReply(cookie Cookie) (*ListHostsReply, error)
func (*Conn) ListHostsRequest ¶
func (*Conn) ListInstalledColormaps ¶
func (c *Conn) ListInstalledColormaps(Window Id) (*ListInstalledColormapsReply, error)
func (*Conn) ListInstalledColormapsReply ¶
func (c *Conn) ListInstalledColormapsReply(cookie Cookie) (*ListInstalledColormapsReply, error)
func (*Conn) ListInstalledColormapsRequest ¶
func (*Conn) ListProperties ¶
func (c *Conn) ListProperties(Window Id) (*ListPropertiesReply, error)
func (*Conn) ListPropertiesReply ¶
func (c *Conn) ListPropertiesReply(cookie Cookie) (*ListPropertiesReply, error)
func (*Conn) ListPropertiesRequest ¶
func (*Conn) LookupColor ¶
func (c *Conn) LookupColor(Cmap Id, Name string) (*LookupColorReply, error)
func (*Conn) LookupColorReply ¶
func (c *Conn) LookupColorReply(cookie Cookie) (*LookupColorReply, error)
func (*Conn) MapSubwindows ¶
func (*Conn) NoOperation ¶
func (c *Conn) NoOperation()
func (*Conn) PollForEvent ¶
PollForEvent returns the next event from the server if one is available in the internal queue. It will not read from the connection, so you must call WaitForEvent to receive new events. Only use this function to empty the queue without blocking.
func (*Conn) PolyFillRectangle ¶
func (*Conn) PolyRectangle ¶
func (*Conn) PolyText16 ¶
func (*Conn) QueryBestSize ¶
func (*Conn) QueryBestSizeReply ¶
func (c *Conn) QueryBestSizeReply(cookie Cookie) (*QueryBestSizeReply, error)
func (*Conn) QueryBestSizeRequest ¶
func (*Conn) QueryColors ¶
func (c *Conn) QueryColors(Cmap Id, Pixels []uint32) (*QueryColorsReply, error)
func (*Conn) QueryColorsReply ¶
func (c *Conn) QueryColorsReply(cookie Cookie) (*QueryColorsReply, error)
func (*Conn) QueryColorsRequest ¶
func (*Conn) QueryExtension ¶
func (c *Conn) QueryExtension(Name string) (*QueryExtensionReply, error)
func (*Conn) QueryExtensionReply ¶
func (c *Conn) QueryExtensionReply(cookie Cookie) (*QueryExtensionReply, error)
func (*Conn) QueryExtensionRequest ¶
func (*Conn) QueryFontReply ¶
func (c *Conn) QueryFontReply(cookie Cookie) (*QueryFontReply, error)
func (*Conn) QueryFontRequest ¶
func (*Conn) QueryKeymap ¶
func (c *Conn) QueryKeymap() (*QueryKeymapReply, error)
func (*Conn) QueryKeymapReply ¶
func (c *Conn) QueryKeymapReply(cookie Cookie) (*QueryKeymapReply, error)
func (*Conn) QueryKeymapRequest ¶
func (*Conn) QueryPointer ¶
func (c *Conn) QueryPointer(Window Id) (*QueryPointerReply, error)
func (*Conn) QueryPointerReply ¶
func (c *Conn) QueryPointerReply(cookie Cookie) (*QueryPointerReply, error)
func (*Conn) QueryPointerRequest ¶
func (*Conn) QueryTextExtents ¶
func (c *Conn) QueryTextExtents(Font Id, String []Char2b) (*QueryTextExtentsReply, error)
func (*Conn) QueryTextExtentsReply ¶
func (c *Conn) QueryTextExtentsReply(cookie Cookie) (*QueryTextExtentsReply, error)
func (*Conn) QueryTextExtentsRequest ¶
func (*Conn) QueryTreeReply ¶
func (c *Conn) QueryTreeReply(cookie Cookie) (*QueryTreeReply, error)
func (*Conn) QueryTreeRequest ¶
func (*Conn) RecolorCursor ¶
func (*Conn) SetAccessControl ¶
func (*Conn) SetClipRectangles ¶
func (*Conn) SetCloseDownMode ¶
func (*Conn) SetFontPath ¶
func (*Conn) SetModifierMapping ¶
func (c *Conn) SetModifierMapping(KeycodesPerModifier byte, Keycodes []byte) (*SetModifierMappingReply, error)
func (*Conn) SetModifierMappingReply ¶
func (c *Conn) SetModifierMappingReply(cookie Cookie) (*SetModifierMappingReply, error)
func (*Conn) SetModifierMappingRequest ¶
func (*Conn) SetPointerMapping ¶
func (c *Conn) SetPointerMapping(Map []byte) (*SetPointerMappingReply, error)
func (*Conn) SetPointerMappingReply ¶
func (c *Conn) SetPointerMappingReply(cookie Cookie) (*SetPointerMappingReply, error)
func (*Conn) SetPointerMappingRequest ¶
func (*Conn) SetScreenSaver ¶
func (*Conn) SetSelectionOwner ¶
func (*Conn) StoreColors ¶
func (*Conn) StoreNamedColor ¶
func (*Conn) TranslateCoordinates ¶
func (*Conn) TranslateCoordinatesReply ¶
func (c *Conn) TranslateCoordinatesReply(cookie Cookie) (*TranslateCoordinatesReply, error)
func (*Conn) TranslateCoordinatesRequest ¶
func (*Conn) UngrabButton ¶
func (*Conn) UngrabKeyboard ¶
func (*Conn) UngrabPointer ¶
func (*Conn) UngrabServer ¶
func (c *Conn) UngrabServer()
func (*Conn) UninstallColormap ¶
func (*Conn) UnmapSubwindows ¶
func (*Conn) UnmapWindow ¶
func (*Conn) WaitForEvent ¶
WaitForEvent returns the next event from the server. It will block until an event is available.
type Cookie ¶
type Cookie uint16
Cookies are the sequence numbers used to pair replies up with their requests
type CreateNotifyEvent ¶
type DepthInfo ¶
type DepthInfo struct {
Depth byte
VisualsLen uint16
Visuals []VisualInfo
}
type DestroyNotifyEvent ¶
type EnterNotifyEvent ¶
type Event ¶
type Event interface{}
Event is an interface that can contain any of the events returned by the server. Use a type assertion switch to extract the Event structs.
type ExposeEvent ¶
type FocusInEvent ¶
type FocusOutEvent ¶
type FocusOutEvent FocusInEvent
type GetAtomNameReply ¶
type GetFontPathReply ¶
type GetGeometryReply ¶
type GetInputFocusReply ¶
type GetKeyboardControlReply ¶
type GetKeyboardMappingReply ¶
type GetModifierMappingReply ¶
type GetMotionEventsReply ¶
type GetPointerControlReply ¶
type GetPointerMappingReply ¶
type GetPropertyReply ¶
type GetScreenSaverReply ¶
type GetSelectionOwnerReply ¶
type GetSelectionOwnerReply struct {
Owner Id
}
type GetWindowAttributesReply ¶
type GetWindowAttributesReply struct {
BackingStore byte
Visual Id
Class uint16
BitGravity byte
WinGravity byte
BackingPlanes uint32
BackingPixel uint32
SaveUnder bool
MapIsInstalled bool
MapState byte
OverrideRedirect bool
Colormap Id
AllEventMasks uint32
YourEventMask uint32
DoNotPropagateMask uint16
}
type GrabKeyboardReply ¶
type GrabKeyboardReply struct {
Status byte
}
type GrabPointerReply ¶
type GrabPointerReply struct {
Status byte
}
type GraphicsExposureEvent ¶
type InternAtomReply ¶
type InternAtomReply struct {
Atom Id
}
type KeyPressEvent ¶
type KeyReleaseEvent ¶
type KeyReleaseEvent KeyPressEvent
type KeymapNotifyEvent ¶
type KeymapNotifyEvent struct {
Keys [31]byte
}
type LeaveNotifyEvent ¶
type LeaveNotifyEvent EnterNotifyEvent
type ListExtensionsReply ¶
type ListFontsReply ¶
type ListFontsWithInfoReply ¶
type ListFontsWithInfoReply struct {
NameLen byte
MinBounds Charinfo
MaxBounds Charinfo
MinCharOrByte2 uint16
MaxCharOrByte2 uint16
DefaultChar uint16
PropertiesLen uint16
DrawDirection byte
MinByte1 byte
MaxByte1 byte
AllCharsExist bool
FontAscent int16
FontDescent int16
RepliesHint uint32
Properties []Fontprop
Name []byte
}
type ListHostsReply ¶
type ListPropertiesReply ¶
type LookupColorReply ¶
type MapNotifyEvent ¶
type MapRequestEvent ¶
type MappingNotifyEvent ¶
type MotionNotifyEvent ¶
type NoExposureEvent ¶
type PropertyNotifyEvent ¶
type QueryBestSizeReply ¶
type QueryColorsReply ¶
type QueryExtensionReply ¶
type QueryFontReply ¶
type QueryFontReply struct {
MinBounds Charinfo
MaxBounds Charinfo
MinCharOrByte2 uint16
MaxCharOrByte2 uint16
DefaultChar uint16
PropertiesLen uint16
DrawDirection byte
MinByte1 byte
MaxByte1 byte
AllCharsExist bool
FontAscent int16
FontDescent int16
CharInfosLen uint32
Properties []Fontprop
CharInfos []Charinfo
}
type QueryKeymapReply ¶
type QueryKeymapReply struct {
Keys [32]byte
}
type QueryPointerReply ¶
type QueryTextExtentsReply ¶
type QueryTreeReply ¶
type ReparentNotifyEvent ¶
type ResizeRequestEvent ¶
type ScreenInfo ¶
type ScreenInfo struct {
Root Id
DefaultColormap Id
WhitePixel uint32
BlackPixel uint32
CurrentInputMasks uint32
WidthInPixels uint16
HeightInPixels uint16
WidthInMillimeters uint16
HeightInMillimeters uint16
MinInstalledMaps uint16
MaxInstalledMaps uint16
RootVisual Id
BackingStores byte
SaveUnders bool
RootDepth byte
AllowedDepthsLen byte
AllowedDepths []DepthInfo
}
type SelectionClearEvent ¶
type SelectionNotifyEvent ¶
type SelectionRequestEvent ¶
type SetModifierMappingReply ¶
type SetModifierMappingReply struct {
Status byte
}
type SetPointerMappingReply ¶
type SetPointerMappingReply struct {
Status byte
}
type SetupInfo ¶
type SetupInfo struct {
Status byte
ProtocolMajorVersion uint16
ProtocolMinorVersion uint16
Length uint16
ReleaseNumber uint32
ResourceIdBase uint32
ResourceIdMask uint32
MotionBufferSize uint32
VendorLen uint16
MaximumRequestLength uint16
RootsLen byte
PixmapFormatsLen byte
ImageByteOrder byte
BitmapFormatBitOrder byte
BitmapFormatScanlineUnit byte
BitmapFormatScanlinePad byte
MinKeycode byte
MaxKeycode byte
Vendor []byte
PixmapFormats []Format
Roots []ScreenInfo
}